pub struct DirtyWireframeSpecializations(pub DirtySpecializations);Expand description
Stores information about all entities that have changed in such a way as to potentially require their wireframe pipelines to be re-specialized.
This is separate from DirtySpecializations because a single entity can
have both a mesh and a wireframe on it, and the pipelines are treated
separately.
See DirtySpecializations for more information.
Tuple Fields
0: DirtySpecializationsMethods from Deref<Target = DirtySpecializations>
Sourcepub fn must_wipe_specializations_for_view(
&self,
view: RetainedViewEntity,
) -> bool
pub fn must_wipe_specializations_for_view( &self, view: RetainedViewEntity, ) -> bool
Returns true if the view has changed in such a way that all specialized pipelines for entities visible from it must be regenerated.
Sourcepub fn iter_to_despecialize<'a>(
&'a self,
) -> impl Iterator<Item = &'a MainEntity>
pub fn iter_to_despecialize<'a>( &'a self, ) -> impl Iterator<Item = &'a MainEntity>
Iterates over all entities that need their specializations cleared in this frame.
Sourcepub fn iter_to_specialize<'a>(
&'a self,
view: RetainedViewEntity,
render_view_visible_mesh_entities: &'a RenderVisibleEntitiesClass,
last_frame_view_pending_queues: &'a HashSet<(Entity, MainEntity)>,
) -> impl Iterator<Item = (&'a Entity, &'a MainEntity)>
pub fn iter_to_specialize<'a>( &'a self, view: RetainedViewEntity, render_view_visible_mesh_entities: &'a RenderVisibleEntitiesClass, last_frame_view_pending_queues: &'a HashSet<(Entity, MainEntity)>, ) -> impl Iterator<Item = (&'a Entity, &'a MainEntity)>
Iterates over all entities that need to have their pipelines re-specialized this frame.
last_frame_view_pending_queues should be the contents of the
ViewPendingQueues::prev_frame list.
Sourcepub fn iter_to_dequeue<'a>(
&'a self,
view: RetainedViewEntity,
render_visible_mesh_entities: &'a RenderVisibleEntitiesClass,
) -> impl Iterator<Item = &'a MainEntity>
pub fn iter_to_dequeue<'a>( &'a self, view: RetainedViewEntity, render_visible_mesh_entities: &'a RenderVisibleEntitiesClass, ) -> impl Iterator<Item = &'a MainEntity>
Iterates over all renderables that should be removed from the phase.
This includes renderables that became invisible this frame, renderables
that are in DirtySpecializations::changed_renderables, and
renderables that are in DirtySpecializations::removed_renderables.
If this view must itself be re-specialized, this will iterate over all
visible entities in addition to those that became invisible.
Sourcepub fn iter_to_queue<'a>(
&'a self,
view: RetainedViewEntity,
render_visible_mesh_entities: &'a RenderVisibleEntitiesClass,
last_frame_view_pending_queues: &'a HashSet<(Entity, MainEntity)>,
) -> impl Iterator<Item = (&'a Entity, &'a MainEntity)>
pub fn iter_to_queue<'a>( &'a self, view: RetainedViewEntity, render_visible_mesh_entities: &'a RenderVisibleEntitiesClass, last_frame_view_pending_queues: &'a HashSet<(Entity, MainEntity)>, ) -> impl Iterator<Item = (&'a Entity, &'a MainEntity)>
Iterates over all renderables that potentially need to be re-queued.
This includes both renderables that became visible and those that are in
DirtySpecializations::changed_renderables. If this view must itself
be re-specialized, this will iterate over all visible renderables.
last_frame_view_pending_queues should be the contents of the
ViewPendingQueues::prev_frame list.